<?php // phpcs:ignore WordPress.NamingConventions
/**
 * This file belongs to the YIT Framework.
 *
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 *
 * @class   YITH_WCDN_Desktop_Notifications_Admin_Premium
 * @author  YITH <plugins@yithemes.com>
 * @package YITH\YITH_Desktop_Notifications_Premium\Classes
 */

if ( ! defined( 'YITH_WCDN_VERSION' ) ) {
	exit( 'Direct access forbidden.' );
}

/**
 * Admin class for premium version
 *
 * @class      YITH_WCDN_Desktop_Notifications_Admin
 * @package    Yithemes
 * @since      Version 1.0.0
 */

if ( ! class_exists( 'YITH_WCDN_Desktop_Notifications_Admin_Premium' ) ) {
	/**
	 * Class YITH_WCDN_Desktop_Notifications_Admin_Premium
	 *
	 */
	class YITH_WCDN_Desktop_Notifications_Admin_Premium extends YITH_WCDN_Desktop_Notifications_Admin {

		/**
		 * _panel
		 *
		 * @var Panel object
		 */
		protected $_panel = null;


		/**
		 * _panel_page
		 *
		 * @var Panel page
		 */
		protected $_panel_page = 'yith_wcdn_panel_desktop_notifications';

		/**
		 * _official_documentation
		 *
		 * @var string Official plugin documentation
		 */
		protected $_official_documentation = 'https://yithemes.com/docs-plugins/yith-woocommerce-multi-step-checkout/';

		/**
		 * Single instance of the class
		 *
		 * @var \YITH_WCDN_Desktop_Notifications_Admin_Premium
		 * @since 1.0.0
		 */
		protected static $instance;


		/**
		 * Construct
		 *
		 * @since 1.0
		 */
		public function __construct() {
			/* === Register Panel Settings === */
			$this->show_premium_landing = false;
			add_filter( 'yith_wcdn_admin_tabs', array( $this, 'register_admin_tabs' ) );

			// custom tab.
			add_action( 'yith_wcdn_upload_tab', array( $this, 'upload_tab' ), 10, 2 );

			parent::__construct();
		}

		/**
		 * Add a panel under YITH Plugins tab
		 *
		 * @param  mixed $admin_tabs yith admin panel tabs.
		 * @return   array
		 * @since    1.0
		 * @use     /Yit_Plugin_Panel class
		 * @see      plugin-fw/lib/yit-plugin-panel.php
		 */
		public function register_admin_tabs( $admin_tabs ) {

			$admin_tabs['upload'] = esc_html__( 'Upload', 'yith-desktop-notifications-for-woocommerce' );

			return $admin_tabs;
		}


		/**
		 * Sidebar links
		 *
		 * @return   array The links
		 * @since    1.2.1
		 */
		public function get_sidebar_link() {
			$links = array(
				/*
				array(
					'title' => esc_html__( 'Plugin documentation', 'yith-desktop-notifications-for-woocommerce' ),
					'url'   => $this->_official_documentation,
				),*/
				array(
					'title' => esc_html__( 'Help Center', 'yith-desktop-notifications-for-woocommerce' ),
					'url'   => 'https://support.yithemes.com/hc/en-us/categories/202568518-Plugins',
				),
				array(
					'title' => esc_html__( 'Support platform', 'yith-desktop-notifications-for-woocommerce' ),
					'url'   => 'https://yithemes.com/my-account/support/dashboard/',
				),
				/*
				array(
					'title' => sprintf( '%s (%s %s)', esc_html__( 'Changelog', 'yith-desktop-notifications-for-woocommerce' ), esc_html__( 'current version', 'yith-desktop-notifications-for-woocommerce' ), YITH_WCDN_VERSION ),
					'url'   => 'https://yithemes.com/docs-plugins/yith-woocommerce-multi-step-checkout/07-changelog-premium.html',
				),*/
			);

			return $links;
		}



		/**
		 * Enqueue styles and scripts
		 *
		 * @access public
		 * @return void
		 * @since 1.0.0
		 */
		public function enqueue_styles_scripts() {

			wp_register_style( 'yith_wcdn_backend_premium', YITH_WCDN_ASSETS_URL . 'css/backend-premium.css', false, YITH_WCDN_VERSION, false );
			wp_register_script( 'yith_wcdn_admin_premium', YITH_WCDN_ASSETS_URL . 'js/wcdn-admin-premium.js', array( 'jquery', 'jquery-ui-sortable', 'wc-enhanced-select' ), YITH_WCDN_VERSION, true );
			wp_register_script( 'yith_wcdn_media_lib', YITH_WCDN_ASSETS_URL . 'js/wcdn-media-lib-uploader.js', array( 'jquery' ), YITH_WCDN_VERSION, true );

			/** APPLY_FILTERS: yith_wcdn_admin_localize
			*
			* Filter the admin localized params.
			*/
			wp_localize_script(
				'yith_wcdn_admin_premium',
				'yith_wcdn_admin',
				apply_filters(
					'yith_wcdn_admin_localize',
					array(
						'ajaxurl'       => admin_url( 'admin-ajax.php' ),
						'vendor_active' => ! ! defined( 'YITH_WPV_PREMIUM' ) && YITH_WPV_PREMIUM,
						'nonce'         => wp_create_nonce( 'yith_wcdn_ajax-premium' ),
					)
				)
			);

			if ( is_admin() && isset( $_REQUEST['page'] ) && 'yith_wcdn_panel_desktop_notifications' === $_REQUEST['page'] ) { // phpcs:ignore WordPress.Security.NonceVerification
				wp_enqueue_style( 'yith_wcdn_backend_premium' );
				wp_enqueue_script( 'yith_wcdn_admin_premium' );
				wp_enqueue_script( 'yith_wcdn_media_lib' );
			}

		}

		/**
		 * Print upload table
		 *
		 * @access public
		 * @return void
		 * @since 1.0.0
		 */
		public function upload_tab() {
			if ( isset( $_GET['tab'] ) && isset( $_GET['page'] ) && $_GET['page'] === $this->_panel_page && file_exists( YITH_WCDN_TEMPLATE_PATH . 'admin/upload-panel.php' ) ) { // phpcs:ignore WordPress.Security.NonceVerification
				$type = sanitize_text_field( wp_unslash( $_GET['tab'] ) ); // phpcs:ignore WordPress.Security.NonceVerification
				include_once YITH_WCDN_TEMPLATE_PATH . 'admin/upload-panel.php';
			}
		}

		/**
		 * Load the notifications.
		 *
		 * @param  mixed $type notification type.
		 * @return void
		 */
		public function load_notifications( $type ) {
			if ( isset( $_GET['page'] ) && $_GET['page'] === $this->_panel_page && file_exists( YITH_WCDN_TEMPLATE_PATH . 'admin/' . $type . '-load-options-premium.php' ) ) { // phpcs:ignore WordPress.Security.NonceVerification
				?>
				<p id="yith_button_new_notification">
					<a href="" id="yith-wcdn-add-section-button" class="button-secondary" data-section_id="yit_wcdn_options_<?php echo esc_html( $type ); ?>-rules" data-action="yit_wcdn_add_section" data-type="<?php echo $type; ?>" data-section_name="yit_wcdn_options[<?php echo $type; ?>-rules]"><?php _e( 'Add new notification', 'yith-desktop-notifications-for-woocommerce' ); ?></a>
					<span class="yith-wcdn-error-input-section"></span>
				</p>
				<?php
				$db_value = get_option( 'yith-wcdn-desktop-notifications' );
				include_once YITH_WCDN_TEMPLATE_PATH . 'admin/' . $type . '-load-options-premium.php';
			}
		}

		/**
		 * Plugin Row Meta
		 *
		 * @param  array  $new_row_meta_args new metadata to add to the plugin activation panel.
		 * @param  array  $plugin_meta Contains the plugin version and author, etc.
		 * @param  string $plugin_file Init plugin file.
		 * @param  array  $plugin_data The plugin data.
		 * @param  string $status the plugin status.
		 * @param  string $init_file the init file.
		 * @return array
		 *
		 * @since    1.2.3
		 */
		public function plugin_row_meta( $new_row_meta_args, $plugin_meta, $plugin_file, $plugin_data, $status, $init_file = 'YITH_WCDN_INIT' ) {
			$new_row_meta_args = parent::plugin_row_meta( $new_row_meta_args, $plugin_meta, $plugin_file, $plugin_data, $status, $init_file );

			if ( defined( $init_file ) && constant( $init_file ) === $plugin_file ) {
				$new_row_meta_args['is_premium'] = true;
			}

			return $new_row_meta_args;
		}

		/**
		 * Regenerate auction prices
		 *
		 * Action Links
		 *
		 * @param array $links Plugin links.
		 * @return array
		 * @since    1.2.3
		 */
		public function action_links( $links ) {
			$links = yith_add_action_links( $links, $this->_panel_page, true, YITH_WCDN_SLUG );
			return $links;
		}

	}
}
