<?php // phpcs:ignore WordPress.NamingConventions
/**
 * This file belongs to the YIT Framework.
 *
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 *
 * @class   YITH_WCDN_Desktop_Notifications_Admin
 * @author  YITH <plugins@yithemes.com>
 * @package YITH\YITH_Desktop_Notifications_Premium\Classes
 */

if ( ! defined( 'YITH_WCDN_VERSION' ) ) {
	exit( 'Direct access forbidden.' );
}

/**
 * Admin class for free version
 *
 * @class      YITH_WCDN_Desktop_Notifications_Admin
 * @package    Yithemes
 * @since      Version 1.0.0
 */

if ( ! class_exists( 'YITH_WCDN_Desktop_Notifications_Admin' ) ) {
	/**
	 * Class YITH_WCDN_Desktop_Notifications_Admin
	 *
	 */
	class YITH_WCDN_Desktop_Notifications_Admin {

		/**
		 * _panel
		 *
		 * @var Panel object
		 */
		protected $_panel = null;

		/**
		 * _panel_page
		 *
		 * @var string  Panel page
		 */
		protected $_panel_page = 'yith_wcdn_panel_desktop_notifications';

		/**
		 * Show the premium landing page
		 *
		 * @var bool show_premium_landing
		 */
		public $show_premium_landing = true;

		/**
		 * Official plugin documentation
		 *
		 * @var string _official_documentation
		 */
		protected $_official_documentation = 'https://docs.yithemes.com/yith-desktop-notifications-for-woocommerce/';

		/**
		 * Official plugin page
		 *
		 * @var string _premium_landing_url
		 */
		protected $_premium_landing_url = 'https://yithemes.com/themes/plugins/yith-woocommerce-desktop-notifications/';

		/**
		 * Single instance of the class
		 *
		 * @var \YITH_WCDN_Desktop_Notifications_Admin
		 * @since 1.0.0
		 */
		protected static $instance;


		/**
		 * Returns single instance of the class
		 *
		 * @return \YITH_WCDN_Desktop_Notifications_Admin
		 * @since 1.0.0
		 */
		public static function get_instance() {
			$self = __CLASS__ . ( class_exists( __CLASS__ . '_Premium' ) ? '_Premium' : '' );

			if ( is_null( $self::$instance ) ) {
				$self::$instance = new $self();
			}

			return $self::$instance;
		}


		/**
		 * Construct
		 *
		 * @since 1.0
		 */
		public function __construct() {
			/* === Register Panel Settings === */
			add_action( 'admin_menu', array( $this, 'register_panel' ), 5 );

			/* === Premium Tab === */
			add_action( 'yith_wcdn_premium_tab', array( $this, 'show_premium_landing' ) );

			// Enqueue Scripts.
			add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_styles_scripts' ), 11 );
			// Custom tab.
			add_action( 'yith_wcdn_notifications_tab', array( $this, 'notifications_tab' ), 10, 2 );
			add_action( 'yith_wcdn_print_notifications', array( $this, 'load_notifications' ), 10 );

			/* === Show Plugin Information === */
			add_filter( 'plugin_action_links_' . plugin_basename( YITH_WCDN_PATH . '/' . basename( YITH_WCDN_FILE ) ), array( $this, 'action_links' ) );
			add_filter( 'yith_show_plugin_row_meta', array( $this, 'plugin_row_meta' ), 10, 5 );

		}

		/**
		 * Retrieve the documentation URL.
		 *
		 * @return string
		 */
		protected function get_doc_url(): string {
			return 'https://docs.yithemes.com/yith-desktop-notifications-for-woocommerce/?_gl=1%2A16c2m2t%2A_ga%2AMjAzMjE1NjQ2My4xNjc1NDM2ODQ2%2A_ga_07N4GJ6E0Y%2AMTY5NDUyNjQ3Ny41NTYuMS4xNjk0NTI3NTY4LjU5LjAuMA..%2A_gcl_aw%2AR0NMLjE2ODY5MTU3MTguQ2p3S0NBandrTENrQmhBOUVpd0FrYTlRUml4TVN1TkdDRWZYQTl4NUxjWlVySDhnRXFCOVpCSjN1WE4zYVVNX0NXcWVnYl9JWnoyMUJob0NOM1FRQXZEX0J3RQ..%2A_gcl_au%2ANjY3NTI1MTY2LjE2OTEwNzM3NzE.';
		}

		/**
		 * Add a panel under YITH Plugins tab
		 *
		 * @return   void
		 * @since    1.0
		 * @use     /Yit_Plugin_Panel class
		 * @see      plugin-fw/lib/yit-plugin-panel.php
		 */
		public function register_panel() {

			if ( ! empty( $this->_panel ) ) {
				return;
			}

			/** APPLY_FILTERS: yith_wcdn_admin_tabs
			*
			* Filter the default admin tabs.
			*/
			$admin_tabs = apply_filters(
				'yith_wcdn_admin_tabs',
				array(
					'settings'      => esc_html__( 'Settings', 'yith-desktop-notifications-for-woocommerce' ),
					'notifications' => esc_html__( 'Notifications', 'yith-desktop-notifications-for-woocommerce' ),
				)
			);

			if ( $this->show_premium_landing ) {
				$admin_tabs['premium'] = esc_html__( 'Premium Version', 'yith-desktop-notifications-for-woocommerce' );
			}

			$args = array(
				'create_menu_page' => true,
				'parent_slug'      => '',
				'page_title'       => 'YITH Desktop Notifications for WooCommerce',
				'menu_title'       => 'Desktop Notifications',
				'capability'       => 'manage_options',
				'parent'           => 'yith-woocommerce-desktop-notifications',
				'parent_page'      => 'yith_plugin_panel',
				'class'            => yith_set_wrapper_class(),
				'page'             => $this->_panel_page,
				'admin-tabs'       => $admin_tabs,
				'options-path'     => YITH_WCDN_OPTIONS_PATH,
				'links'            => $this->get_sidebar_link(),
				'plugin_slug'      => YITH_WCDN_SLUG,
				'is_premium'       => defined( 'YITH_WCDN_PREMIUM' ),
				'help_tab'         => array(
					'hc_url'  => 'https://yithemes.com/themes/plugins/yith-woocommerce-desktop-notifications/#tab-faqs_tab',
					'doc_url' => $this->get_doc_url(),
				),
			);

			/* === Fixed: not updated theme/old plugin framework  === */
			if ( ! class_exists( 'YIT_Plugin_Panel_WooCommerce' ) ) {
				require_once 'plugin-fw/lib/yit-plugin-panel-wc.php';
			}

			$this->_panel = new YIT_Plugin_Panel_WooCommerce( $args );

			add_action( 'woocommerce_admin_field_yith_desktop_notifications_upload', array( $this->_panel, 'yit_upload' ), 10, 1 );
		}


		/**
		 * Show the premium landing
		 *
		 * @since 1.0.0
		 * @return void
		 */
		public function show_premium_landing() {
			if ( file_exists( YITH_WCDN_TEMPLATE_PATH . 'premium/premium.php' ) && $this->show_premium_landing ) {
				require_once YITH_WCDN_TEMPLATE_PATH . 'premium/premium.php';
			}
		}

		/**
		 * Sidebar links
		 *
		 * @return   array The links
		 * @since    1.2.1
		 */
		public function get_sidebar_link() {
			$links = array(
				array(
					'title' => esc_html__( 'Plugin documentation', 'yith-desktop-notifications-for-woocommerce' ),
					'url'   => $this->_official_documentation,
				),
				array(
					'title' => esc_html__( 'Help Center', 'yith-desktop-notifications-for-woocommerce' ),
					'url'   => 'https://support.yithemes.com/hc/en-us/categories/202568518-Plugins',
				),
				array(
					'title' => esc_html__( 'Support platform', 'yith-desktop-notifications-for-woocommerce' ),
					'url'   => 'https://yithemes.com/my-account/support/dashboard/',
				),
				/*
				array(
					'title' => sprintf( '%s (%s %s)', esc_html__( 'Changelog', 'yith-desktop-notifications-for-woocommerce' ), esc_html__( 'current version', 'yith-desktop-notifications-for-woocommerce' ), YITH_WCDN_VERSION ),
					'url'   => 'https://yithemes.com/docs-plugins/yith-woocommerce-multi-step-checkout/07-changelog-premium.html',
				),*/
			);

			return $links;
		}



		/**
		 * Enqueue styles and scripts
		 *
		 * @access public
		 * @return void
		 * @since 1.0.0
		 */
		public function enqueue_styles_scripts() {

			wp_register_style( 'yith_wcdn_backend', YITH_WCDN_ASSETS_URL . 'css/backend.css', false, YITH_WCDN_VERSION, false );
			wp_register_script( 'yith_wcdn_admin', YITH_WCDN_ASSETS_URL . 'js/wcdn-admin.js', array( 'jquery', 'jquery-ui-sortable', 'wc-enhanced-select' ), YITH_WCDN_VERSION, true );

			wp_localize_script(
				'yith_wcdn_admin',
				'yith_wcdn_admin',
				apply_filters(
					'yith_wcdn_admin_localize',
					array(
						'ajaxurl' => admin_url( 'admin-ajax.php' ),
						'nonce'   => wp_create_nonce( 'yith_wcdn_ajax-free' ),
					)
				)
			);

			if ( is_admin() ) {
				wp_enqueue_style( 'yith_wcdn_backend' );
				wp_enqueue_script( 'yith_wcdn_admin' );
			}

		}

		/**
		 * Print notifications table
		 *
		 * @access public
		 * @return void
		 * @since 1.0.0
		 */
		public function notifications_tab() {
			if ( isset( $_GET['tab'] ) && isset( $_GET['page'] ) && $_GET['page'] === $this->_panel_page && file_exists( YITH_WCDN_TEMPLATE_PATH . 'admin/notifications-panel.php' ) ) { // phpcs:ignore WordPress.Security.NonceVerification
				$type = sanitize_text_field( wp_unslash( $_GET['tab'] ) ); // phpcs:ignore WordPress.Security.NonceVerification
				include_once YITH_WCDN_TEMPLATE_PATH . 'admin/notifications-panel.php';
			}
		}

		/**
		 * Get the premium landing uri
		 *
		 * @since   1.0.0
		 * @return  string The premium landing link
		 */
		public function get_premium_landing_uri() {
			return defined( 'YITH_REFER_ID' ) ? $this->_premium_landing_url . '?refer_id=' . YITH_REFER_ID : $this->_premium_landing_url . '?refer_id=1030585';
		}

		/**
		 * Load the notifications.
		 *
		 * @param  mixed $type notification type.
		 * @return void
		 */
		public function load_notifications( $type ) {
			if ( isset( $_GET['page'] ) && $_GET['page'] === $this->_panel_page && file_exists( YITH_WCDN_TEMPLATE_PATH . 'admin/' . $type . '-load-options.php' ) ) { // phpcs:ignore WordPress.Security.NonceVerification
				$db_value = get_option( 'yith-wcdn-desktop-notifications-free' );
				include_once YITH_WCDN_TEMPLATE_PATH . 'admin/' . $type . '-load-options.php';
			}
		}

		/**
		 * Regenerate auction prices
		 *
		 * Action Links
		 *
		 * @param array $links Plugin links.
		 * @return array
		 * @since    1.2.3
		 */
		public function action_links( $links ) {
			$links = yith_add_action_links( $links, $this->_panel_page, false );
			return $links;
		}

		/**
		 * Plugin Row Meta
		 *
		 * @param  array  $new_row_meta_args new metadata to add to the plugin activation panel.
		 * @param  array  $plugin_meta Contains the plugin version and author, etc.
		 * @param  string $plugin_file Init plugin file.
		 * @param  array  $plugin_data The plugin data.
		 * @param  string $status the plugin status.
		 * @param  string $init_file the init file.
		 * @return array
		 *
		 * @since    1.2.3
		 */
		public function plugin_row_meta( $new_row_meta_args, $plugin_meta, $plugin_file, $plugin_data, $status, $init_file = 'YITH_WCDN_FREE_INIT' ) {
			if ( defined( $init_file ) && constant( $init_file ) === $plugin_file ) {
				$new_row_meta_args['slug'] = YITH_WCDN_SLUG;
			}

			return $new_row_meta_args;
		}
	}
}
