<?php // phpcs:ignore WordPress.NamingConventions
/**
 * Notes class
 *
 * @author  YITH <plugins@yithemes.com>
 * @package YITH Desktop Notifications for WooCommerce
 * @version 1.0.0
 *
 * @class   YITH_WCDN_Desktop_Notifications_Ajax_Premium
 * @package YITH\YITH_Desktop_Notifications_Premium\Classes
 */

if ( ! defined( 'YITH_WCDN_VERSION' ) ) {
	exit( 'Direct access forbidden.' );
}

if ( ! class_exists( 'YITH_WCDN_Desktop_Notifications_Ajax_Premium' ) ) {
	/**
	 * YITH_WCDN_Desktop_Notifications_Ajax
	 *
	 * @since 1.0.0
	 */
	class YITH_WCDN_Desktop_Notifications_Ajax_Premium extends YITH_WCDN_Desktop_Notifications_Ajax {

		/**
		 * Single instance of the class
		 *
		 * @var \YITH_WCDN_Desktop_Notifications_Ajax
		 * @since 1.0.0
		 */
		protected static $instance;

		/**
		 * Constructor
		 *
		 * @since  1.0.0
		 */
		public function __construct() {
			add_action( 'wp_ajax_yith_wcdn_update_notifications', array( $this, 'yith_wcdn_update_notifications' ) );
			add_action( 'wp_ajax_yith_wcdn_delete_notifications', array( $this, 'yith_wcdn_delete_notifications' ) );
			add_action( 'wp_ajax_yith_wcdn_add_audio', array( $this, 'yith_wcdn_add_audio' ) );

			parent::__construct();
		}

		/**
		 * Save notifications
		 *
		 * @since  1.0.0
		 */
		public function yith_wcdn_save_notification() {
			if ( check_ajax_referer( 'yith_wcdn_ajax-premium', 'security' ) && isset( $_POST['key'] ) ) {
				$global_desktop_notifications = get_option( 'yith-wcdn-desktop-notifications' );
				$option_notification          = array(
					'notification'      => isset( $_POST['notification'] ) ? sanitize_text_field( wp_unslash( $_POST['notification'] ) ) : '',
					'title'             => ( ! isset( $_POST['title'] ) || '' === $_POST['title'] ) ? __( 'Notification', 'yith-desktop-notifications-for-woocommerce' ) : sanitize_text_field( wp_unslash( $_POST['title'] ) ),
					'description'       => isset( $_POST['description'] ) ? sanitize_text_field( wp_unslash( $_POST['description'] ) ) : '',
					'role_user'         => isset( $_POST['role_user'] ) ? map_deep( wp_unslash( $_POST['role_user'] ), 'sanitize_text_field' ) : '',

					/** APPLY_FILTERS: yith_wcdn_change_protocol
					*
					* Filter the icon or the sound when saving the notifications.
					*
					* @param $_POST['image'] Default selected option.
					*/
					'icon'              => isset( $_POST['image'] ) ? apply_filters( 'yith_wcdn_change_protocol', sanitize_text_field( wp_unslash( $_POST['image'] ) ) ) : apply_filters( 'yith_wcdn_change_protocol' ),
					'sound'             => isset( $_POST['sound'] ) ? apply_filters( 'yith_wcdn_change_protocol', sanitize_text_field( wp_unslash( $_POST['sound'] ) ) ) : apply_filters( 'yith_wcdn_change_protocol' ),
					'time_notification' => isset( $_POST['time_notification'] ) ? intval( wp_unslash( $_POST['time_notification'] ) ) : 0,
					'active'            => 'yes',
					'url'               => null,
				);

				if ( isset( $_POST['specific_status'] ) ) {
					$option_notification['specific_status'] = map_deep( wp_unslash( $_POST['specific_status'] ), 'sanitize_text_field' );
				}
				if ( isset( $_POST['products'] ) ) {
					$option_notification['products'] = map_deep( wp_unslash( $_POST['products'] ), 'intval' );
				}

				$global_desktop_notifications[ sanitize_text_field( wp_unslash( $_POST['key'] ) ) ] = $option_notification;

				update_option( 'yith-wcdn-desktop-notifications', $global_desktop_notifications );
				die();
			}
		}

		/**
		 * Update notifications
		 *
		 * @since  1.0.0
		 */
		public function yith_wcdn_update_notifications() {
			if ( check_ajax_referer( 'yith_wcdn_ajax-premium', 'security' ) && isset( $_POST['key'] ) ) {
				$notification_key             = sanitize_text_field( wp_unslash( $_POST['key'] ) );
				$global_desktop_notifications = get_option( 'yith-wcdn-desktop-notifications' );

				if ( array_key_exists( $notification_key, $global_desktop_notifications ) ) {

					$option_notification = array(
						'notification'      => isset( $_POST['notification'] ) ? sanitize_text_field( wp_unslash( $_POST['notification'] ) ) : '',
						'title'             => ( ! isset( $_POST['title'] ) || '' === $_POST['title'] ) ? __( 'Notification', 'yith-desktop-notifications-for-woocommerce' ) : sanitize_text_field( wp_unslash( $_POST['title'] ) ),
						'description'       => isset( $_POST['description'] ) ? sanitize_text_field( wp_unslash( $_POST['description'] ) ) : '',
						'role_user'         => isset( $_POST['role_user'] ) ? map_deep( wp_unslash( $_POST['role_user'] ), 'sanitize_text_field' ) : '',
						'icon'              => isset( $_POST['image'] ) ? apply_filters( 'yith_wcdn_change_protocol', sanitize_text_field( wp_unslash( $_POST['image'] ) ) ) : apply_filters( 'yith_wcdn_change_protocol' ),
						'sound'             => isset( $_POST['sound'] ) ? apply_filters( 'yith_wcdn_change_protocol', sanitize_text_field( wp_unslash( $_POST['sound'] ) ) ) : apply_filters( 'yith_wcdn_change_protocol' ),
						'time_notification' => isset( $_POST['time_notification'] ) ? intval( wp_unslash( $_POST['time_notification'] ) ) : 0,
						'active'            => 'yes',
						'url'               => null,
					);

					if ( isset( $_POST['specific_status'] ) ) {
						$option_notification['specific_status'] = map_deep( wp_unslash( $_POST['specific_status'] ), 'sanitize_text_field' );
					}

					if ( isset( $_POST['products'] ) ) {
						$option_notification['products'] = map_deep( wp_unslash( $_POST['products'] ), 'intval' );
					}

					$global_desktop_notifications[ sanitize_text_field( wp_unslash( $_POST['key'] ) ) ] = $option_notification;

					update_option( 'yith-wcdn-desktop-notifications', $global_desktop_notifications );
				}
				die();
			}
		}
		/**
		 * Delete notifications
		 *
		 * @since  1.0.0
		 */
		public function yith_wcdn_delete_notifications() {
			if ( check_ajax_referer( 'yith_wcdn_ajax-premium', 'security' ) && isset( $_POST['key'] ) ) {
				$global_desktop_notifications = get_option( 'yith-wcdn-desktop-notifications' );
				$notification_key             = sanitize_text_field( wp_unslash( $_POST['key'] ) );

				if ( array_key_exists( $notification_key, $global_desktop_notifications ) ) {
					unset( $global_desktop_notifications[ $_POST['key'] ] );
					update_option( 'yith-wcdn-desktop-notifications', $global_desktop_notifications );
				}

				die();
			}
		}

		/**
		 * Get notifications to send the user
		 *
		 * @since  1.0.0
		 */
		public function yith_wcdn_display_notifications() {
			$current_user       = wp_get_current_user();
			$id_current_user    = isset( $current_user->ID ) ? $current_user->ID : '';
			$role_current_user  = $current_user->roles;
			$user_notifications = array();
			$instance           = YITH_Desktop_Notifications()->register_notifications;
			$notifications      = $instance->get_notifications_by_user( $current_user );
			if ( $notifications && is_array( $notifications ) ) {
				foreach ( $notifications as $notification ) {

					$roles         = (array) unserialize( $notification->user_roles_to_notify ); //phpcs:ignore -- Serialized data has known vulnerability problems with Object Injection. JSON is generally a better approach for serializing data
					$user_notified = (array) unserialize( $notification->notified_users ); //phpcs:ignore -- Serialized data has known vulnerability problems with Object Injection. JSON is generally a better approach for serializing data
					$url           = $notification->url;

					foreach ( $role_current_user as $role ) {

						if ( ( in_array( $role, $roles ) || in_array( 'ALL', $roles, true ) ) && ! in_array( $id_current_user, $user_notified, false ) ) {

							if ( isset( $notification->data ) ) {
								$noti = (array) unserialize( $notification->data ); //phpcs:ignore -- Serialized data has known vulnerability problems with Object Injection. JSON is generally a better approach for serializing data

							}
							$noti['url'] = $url;
							$noti['title'] = html_entity_decode( $noti['title'], ENT_QUOTES );
							$noti['description'] = html_entity_decode( $noti['description'], ENT_QUOTES );

							array_push( $user_notifications, $noti );
							// Updated array user notified.
							array_push( $user_notified, $id_current_user );
							$instance->update_notification( $notification->id, serialize( $user_notified ) ); //phpcs:ignore -- Serialized data has known vulnerability problems with Object Injection. JSON is generally a better approach for serializing data
							continue 2;

						}
					}
				}
			}
			wp_send_json( $user_notifications );
		}
	}
}
