<?php // phpcs:ignore WordPress.NamingConventions

/**
 * Notes class
 *
 * @author  YITH <plugins@yithemes.com>
 * @version 1.0.0
 *
 * @class   YITH_WCDN_Desktop_Notifications_Types
 * @package YITH\YITH_Desktop_Notifications_Premium\Classes
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'YITH_WCDN_Desktop_Notifications_Types' ) ) {
	/**
	 * YITH_WCDN_Desktop_Notifications_Notify
	 *
	 * @since 1.0.0
	 */
	class YITH_WCDN_Desktop_Notifications_Types {

		/**
		 * Single instance of the class
		 *
		 * @var \YITH_WCDN_Desktop_Notifications_Types
		 * @since 1.0.0
		 */
		protected static $instance;

		/**
		 * Returns single instance of the class
		 *
		 * @return \YITH_WCDN_Desktop_Notifications_Types
		 * @since 1.0.0
		 */
		public static function get_instance() {
			$self = __CLASS__ . ( class_exists( __CLASS__ . '_Premium' ) ? '_Premium' : '' );

			if ( is_null( $self::$instance ) ) {
				$self::$instance = new $self();
			}

			return $self::$instance;
		}
		/**
		 * Constructor
		 *
		 * @since  1.0.0
		 */
		public function __construct() {
			add_action( 'woocommerce_checkout_order_processed', array( $this, 'yith_wcdn_order_processed' ) );
		}

		/**
		 * Generates the notification when an order is processed
		 *
		 * @param  mixed $order_id order id.
		 * @return void
		 */
		public function yith_wcdn_order_processed( $order_id ) {
			$notifications = get_option( 'yith-wcdn-desktop-notifications-free' );
			$order         = wc_get_order( $order_id );

			do_action( 'yith_wcdn_before_order_notify', $order, $notifications );

				$url_order     = admin_url( 'post.php?post=' . absint( $order_id ) . '&action=edit' );
				$customer_user = yit_get_prop( $order, '_customer_user', true );

				$placeholder = array(
					'{order_id}'    => $order_id,
					'{order_total}' => $order->get_total(),
					'{username}'    => get_user_meta( $customer_user, 'nickname', true ),
				);

				$description                  = strtr( $notifications['description'], $placeholder );
				$notifications['description'] = $description;
				$notifications['url']         = apply_filters( 'yith_wcdn_url_order', $url_order, $order_id, $order );
				$notification_processed       = $notifications;

				$instance = YITH_Desktop_Notifications()->register_notifications;
				$instance->add_notification( $notification_processed );

				do_action( 'yith_wcdn_after_order_notify', $order, $notifications );
		}

	}

}
