<?php // phpcs:ignore WordPress.NamingConventions

/**
 * This file belongs to the YIT Framework.
 *
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 *
 * @class YITH_WCDN_RequestaQuote_Compatibility
 * @package YITH\YITH_Desktop_Notifications_Premium\Classes\Compatibility
 */

if ( ! defined( 'YITH_WCDN_VERSION' ) ) {
	exit( 'Direct access forbidden.' );
}


if ( ! class_exists( 'YITH_WCDN_Compatibility' ) ) {
	/**
	 * YITH_WCDN_Compatibility
	 *
	 * @class      YITH_WCDN_Compatibility
	 * @package    Yithemes
	 * @since      Version 1.0.0
	 * @author     YITH <plugins@yithemes.com>
	 */
	class YITH_WCDN_Compatibility {

		/**
		 * Single instance of the class
		 *
		 * @var \YITH_WCDN_Compatibility
		 * @since 1.0.0
		 */
		protected static $instance;

		/**
		 * Plugins types.
		 *
		 * @var \YITH_WCDN_Compatibility
		 * @since 1.0.0
		 */
		protected $_plugins = array();

		/**
		 * Returns single instance of the class
		 *
		 * @return \YITH_WCDN_Compatibility
		 * @since 1.0.0
		 */
		public static function get_instance() {
			if ( is_null( self::$instance ) ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		/**
		 * __construct
		 *
		 * @return void
		 */
		public function __construct() {
			$this->_plugins = array(
				'multivendor'        => 'Multivendor',
				'request-a-quote'    => 'RequestaQuote',
				'tittle-bar-effects' => 'Tittle_Bar_Effects',
				'bookings'           => 'Bookings',
			);
			$this->_load();
		}

		/**
		 * _load
		 *
		 * @return void
		 */
		private function _load() {
			foreach ( $this->_plugins as $slug => $class_slug ) {
				$filename  = YITH_WCDN_PATH . 'includes/compatibility/class.yith-wcdn-' . $slug . '-compatibility.php';
				$classname = 'YITH_WCDN_' . $class_slug . '_Compatibility';

				$var = str_replace( '-', '_', $slug );
				if ( $this::has_plugin( $slug ) && file_exists( $filename ) && ! function_exists( $classname ) ) {
					require_once $filename;
				}

				if ( function_exists( $classname ) ) {
					$this->$var = $classname();
				}
			}
		}

		/**
		 * Defines environment variables for specified lugins
		 *
		 * @param  mixed $slug slug.
		 * @return string|bool
		 */
		public static function has_plugin( $slug ) {
			switch ( $slug ) {
				case 'multivendor':
					/** APPLY_FILTERS: yith_wcdn_multivendor_min_version
					*
					* Filter the compare version for the multivendor plugin.
					*/
					return defined( 'YITH_WPV_PREMIUM' ) && YITH_WPV_PREMIUM && defined( 'YITH_WPV_VERSION' ) && version_compare( YITH_WPV_VERSION, apply_filters( 'yith_wcdn_multivendor_min_version', '1.5.0' ), '>' );
				case 'request-a-quote':
					/** APPLY_FILTERS: yith_wcdn_request_a_quote_min_version
					*
					* Filter the compare version for the request a quote plugin.
					*/
					return defined( 'YITH_YWRAQ_PREMIUM' ) && YITH_YWRAQ_PREMIUM && defined( 'YITH_YWRAQ_VERSION' ) && version_compare( YITH_YWRAQ_VERSION, apply_filters( 'yith_wcdn_request_a_quote_min_version', '1.5.0' ), '>' );
				case 'tittle-bar-effects':
					/** APPLY_FILTERS: yith_wcdn_tittle_bar_effects_min_version
					*
					* Filter the compare version for the title bar effects plugin.
					*/
					return defined( 'YITH_WTBE_PREMIUM' ) && YITH_WTBE_PREMIUM && defined( 'YITH_WTBE_VERSION' ) && version_compare( YITH_WTBE_VERSION, apply_filters( 'yith_wcdn_tittle_bar_effects_min_version', '0.1.0' ), '>' );
				case 'bookings':
					/** APPLY_FILTERS: yith_wcdn_bookings_min_version
					*
					* Filter the compare version for the booking plugin.
					*/
					return defined( 'YITH_WCBK_PREMIUM' ) && YITH_WCBK_PREMIUM && defined( 'YITH_WCBK_VERSION' ) && version_compare( YITH_WCBK_VERSION, apply_filters( 'yith_wcdn_bookings_min_version', '2.1.2' ), '>' );
				default:
					return false;
			}
		}
	}
}
